# regression.py
class SimpleLinearRegression:
    def __init__(self):
        self.slope = None
        self.intercept = None

    def fit(self, X, y):
        n = len(X)
        mean_x, mean_y = sum(X) / n, sum(y) / n
        numerator = sum((X[i] - mean_x) * (y[i] - mean_y) for i in range(n))
        denominator = sum((X[i] - mean_x) ** 2 for i in range(n))
        self.slope = numerator / denominator
        self.intercept = mean_y - self.slope * mean_x

    def predict(self, X):
        if self.slope is None or self.intercept is None:
            raise ValueError("Model has not been fitted yet!")
        return [self.slope * x + self.intercept for x in X]



from setuptools import setup, find_packages

setup(
    name='aya-linear-regression',
    version='0.1.0',
    packages=find_packages(),
    description='A simple linear regression model from scratch',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author='aya',
    author_email='your.email@example.com',
    url='https://github.com/yourusername/aya-linear-regression',
    license='MIT',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
    ],
    python_requires='>=3.6',
)